summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorross <ross@b067294f-1dea-0310-9683-c47a78595994>2005-09-30 15:20:30 +0000
committerross <ross@b067294f-1dea-0310-9683-c47a78595994>2005-09-30 15:20:30 +0000
commit069c6dbaef61b8a07a606bb177b8fac316f51b67 (patch)
tree81b94fc20dd030a2a8df8a5ca28290d3c725ebb3
parent8231078e453afbe436c205e8bd632d034d446b94 (diff)
Fix invalid windows
git-svn-id: http://svn.o-hand.com/repos/matchbox/trunk/Xoo@1232 b067294f-1dea-0310-9683-c47a78595994
-rw-r--r--ChangeLog8
-rw-r--r--src/main.c3
2 files changed, 10 insertions, 1 deletions
diff --git a/ChangeLog b/ChangeLog
index 2b14719..a7ab0e6 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,11 @@
+2005-09-30 Ross Burton <ross@burtonini.com>
+
+ * data/Xoo.glade:
+ * src/main.c:
+ * src/fakedev.h:
+ Don't set the device image as the back buffer for the fixed
+ window, but rather use a GtkImage like normal people.
+
2005-09-05 Ross Burton <ross@openedhand.com>
* configure.ac:
diff --git a/src/main.c b/src/main.c
index c93d111..f4a7e31 100644
--- a/src/main.c
+++ b/src/main.c
@@ -156,7 +156,8 @@ fakeapp_create_gui (FakeApp * app)
gtk_fixed_move (GTK_FIXED (app->fixed), app->back, 0, 0);
gtk_image_set_from_pixbuf (GTK_IMAGE (app->back), app->device_img);
- /* Now setup the buttons */
+ /* Now setup the buttons. Should do this in realize but we can hack that */
+ gtk_widget_realize (app->fixed);
for (button = app->button_head; button; button = button->next)
{
GtkWidget *eventbox;